#pragma once
#include "Core\iodevices.h"

/*
   FIRST LOOK AT INVERTER.H and INVERTER.CPP FOR COMMENTARY AND INSTRUCTIONS!

   SimpleOutput is an example output device. It is not commented as heavily as
   the inverter example however -- it is assumed you have already pored over that device,
   and just want to see another example of a different class of device.

   This doesn't actually output the data to a file; it merely shows you the WM framework code
   you will need to successfully write an output plugin. It is assumed that you can handle whatever type
   of file IO that you wish to perform.

*/

// Example Output device for World Machine. There are just a few things special that must be done for
// outputs that regular devices don't have to do. See SimpleOutput.cpp for more details
class SimpleOutput :
	public Output
{
public:
	SimpleOutput(void);
	~SimpleOutput(void);

	virtual bool Load(std::istream &in);
	virtual bool Save(std::ostream &out);

	virtual char *GetDescription() { return "Demonstrates how to output things";};
	virtual char *GetTypeName() { return "Simple Output"; };

// NEW Output-class specific function for WM 2.3. 
// Your output functionality should go in here; WM will call this function supplying a packet for tiled builds for example.
	virtual bool doOutput(OutputData &outset, OUTPUT_MODE output_mode);

	// Return false if output is view-only or is otherwise not currently exporting (this helps tiled build and others save time)
	virtual bool isExporting(OUTPUT_MODE mode) { return true; };
	virtual bool isPresetCapable() { return false; };// Allow presets for this device in the generic dialog manager?

	// Output provides a default specialization for Activate. Unless you need to do something unique on Activate, you can simply implement your doOutput call and be good
	// to go! If you do need to perform your own activate, make sure you call Output::Activate() before performing your own actions.
	// virtual bool Activate(BuildContext &context);

//	virtual bool RunUI();	// We need to override the RunUI function to set the filename

protected:
	virtual void doClone(Device *other);	// Copy data from other to this

// Note that you'll need some way to set the filename. You will most likely have to
// override the RunUI() and write a custom dialog box to do so.
	char filename[256];		// filename to output
};
